import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import ContactService from '@/service/contact/contact-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';

/**
 * 联系人视图基类
 *
 * @export
 * @class ContactTabExpViewBase
 * @extends {TabExpViewBase}
 */
export class ContactTabExpViewBase extends TabExpViewBase {

    /**
     * 实体服务对象
     *
     * @type {ContactService}
     * @memberof ContactTabExpViewBase
     */
    protected appEntityService: ContactService = new ContactService;


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof ContactTabExpViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof ContactTabExpViewBase
     */
    protected model: any = {
        srfCaption: 'entities.contact.views.tabexpview.caption',
        srfTitle: 'entities.contact.views.tabexpview.title',
        srfSubTitle: 'entities.contact.views.tabexpview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof ContactTabExpViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '0e4d8b949764a2c40c2b93261aed6fd8';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof ContactTabExpViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof ContactTabExpViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'contact',
            majorPSDEField: 'fullname',
            isLoadDefault: true,
        });
    }



    /**
     * 加载模型
     *
     * @protected
     * @memberof ContactTabExpViewBase
     */
    protected async loadModel(): Promise<any> {
        if(this.context.contact){
            this.appEntityService.getDataInfo(JSON.parse(JSON.stringify(this.context)),{},false).then((response:any) =>{
                if (!response || response.status !== 200) {
                    return;
                }
                const { data: _data } = response;
                if (_data.fullname) {
                    Object.assign(this.model, { dataInfo: _data.fullname });
                    if(this.$route){
                        this.$route.meta.info = this.model.dataInfo;
                    }
                    Object.assign(this.model, { srfTitle: `${this.$t(this.model.srfTitle)} - ${this.model.dataInfo}` });
                    this.$appService.navHistory.setCaption({ tag: this.viewtag, info: this.model.dataInfo });
                }
            })
        }
    }


}